## What is this repository for? ##
* Defining overlays to openCV's VideoCapture class for adding new features
    (simulating different fps, automatic resize of images, ...)
* Providing a displayer handy for non-consuming interactions with the video

## How do I get set up? ##
* Install requirements with `pip install -r requirements.txt`

## Quick example ##
run `python -m skcvideo.reader /path/to/a/video/file.mp4`
